# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from nexus_api_python_client.api_client import ApiClient
from nexus_api_python_client.exceptions import (
    ApiTypeError,
    ApiValueError
)


class ComponentsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_component(self, id, **kwargs):  # noqa: E501
        """Delete a single component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_component(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of the component to delete (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_component_with_http_info(id, **kwargs)  # noqa: E501

    def delete_component_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete a single component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_component_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of the component to delete (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_component" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `delete_component`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/components/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_component_by_id(self, id, **kwargs):  # noqa: E501
        """Get a single component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_component_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of the component to retrieve (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ComponentXO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_component_by_id_with_http_info(id, **kwargs)  # noqa: E501

    def get_component_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get a single component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_component_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of the component to retrieve (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ComponentXO, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_component_by_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_component_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/components/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ComponentXO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_components(self, repository, **kwargs):  # noqa: E501
        """List components  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_components(repository, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository: Repository from which you would like to retrieve components (required)
        :param str continuation_token: A token returned by a prior request. If present, the next page of results are returned
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageComponentXO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_components_with_http_info(repository, **kwargs)  # noqa: E501

    def get_components_with_http_info(self, repository, **kwargs):  # noqa: E501
        """List components  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_components_with_http_info(repository, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository: Repository from which you would like to retrieve components (required)
        :param str continuation_token: A token returned by a prior request. If present, the next page of results are returned
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageComponentXO, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository', 'continuation_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_components" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository' is set
        if self.api_client.client_side_validation and ('repository' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository` when calling `get_components`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'continuation_token' in local_var_params and local_var_params['continuation_token'] is not None:  # noqa: E501
            query_params.append(('continuationToken', local_var_params['continuation_token']))  # noqa: E501
        if 'repository' in local_var_params and local_var_params['repository'] is not None:  # noqa: E501
            query_params.append(('repository', local_var_params['repository']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/components', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageComponentXO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_component(self, repository, **kwargs):  # noqa: E501
        """Upload a single component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_component(repository, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository: Name of the repository to which you would like to upload the component (required)
        :param str yum_directory: yum Directory
        :param file yum_asset: yum Asset 
        :param str yum_asset_filename: yum Asset  Filename
        :param file r_asset: r Asset 
        :param str r_asset_path_id: r Asset  Package Path
        :param file rubygems_asset: rubygems Asset 
        :param file nuget_asset: nuget Asset 
        :param str raw_directory: raw Directory
        :param file raw_asset1: raw Asset 1
        :param str raw_asset1_filename: raw Asset 1 Filename
        :param file raw_asset2: raw Asset 2
        :param str raw_asset2_filename: raw Asset 2 Filename
        :param file raw_asset3: raw Asset 3
        :param str raw_asset3_filename: raw Asset 3 Filename
        :param file pypi_asset: pypi Asset 
        :param file npm_asset: npm Asset 
        :param str maven2_group_id: maven2 Group ID
        :param str maven2_artifact_id: maven2 Artifact ID
        :param str maven2_version: maven2 Version
        :param bool maven2_generate_pom: maven2 Generate a POM file with these coordinates
        :param str maven2_packaging: maven2 Packaging
        :param file maven2_asset1: maven2 Asset 1
        :param str maven2_asset1_classifier: maven2 Asset 1 Classifier
        :param str maven2_asset1_extension: maven2 Asset 1 Extension
        :param file maven2_asset2: maven2 Asset 2
        :param str maven2_asset2_classifier: maven2 Asset 2 Classifier
        :param str maven2_asset2_extension: maven2 Asset 2 Extension
        :param file maven2_asset3: maven2 Asset 3
        :param str maven2_asset3_classifier: maven2 Asset 3 Classifier
        :param str maven2_asset3_extension: maven2 Asset 3 Extension
        :param file apt_asset: apt Asset 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.upload_component_with_http_info(repository, **kwargs)  # noqa: E501

    def upload_component_with_http_info(self, repository, **kwargs):  # noqa: E501
        """Upload a single component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_component_with_http_info(repository, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository: Name of the repository to which you would like to upload the component (required)
        :param str yum_directory: yum Directory
        :param file yum_asset: yum Asset 
        :param str yum_asset_filename: yum Asset  Filename
        :param file r_asset: r Asset 
        :param str r_asset_path_id: r Asset  Package Path
        :param file rubygems_asset: rubygems Asset 
        :param file nuget_asset: nuget Asset 
        :param str raw_directory: raw Directory
        :param file raw_asset1: raw Asset 1
        :param str raw_asset1_filename: raw Asset 1 Filename
        :param file raw_asset2: raw Asset 2
        :param str raw_asset2_filename: raw Asset 2 Filename
        :param file raw_asset3: raw Asset 3
        :param str raw_asset3_filename: raw Asset 3 Filename
        :param file pypi_asset: pypi Asset 
        :param file npm_asset: npm Asset 
        :param str maven2_group_id: maven2 Group ID
        :param str maven2_artifact_id: maven2 Artifact ID
        :param str maven2_version: maven2 Version
        :param bool maven2_generate_pom: maven2 Generate a POM file with these coordinates
        :param str maven2_packaging: maven2 Packaging
        :param file maven2_asset1: maven2 Asset 1
        :param str maven2_asset1_classifier: maven2 Asset 1 Classifier
        :param str maven2_asset1_extension: maven2 Asset 1 Extension
        :param file maven2_asset2: maven2 Asset 2
        :param str maven2_asset2_classifier: maven2 Asset 2 Classifier
        :param str maven2_asset2_extension: maven2 Asset 2 Extension
        :param file maven2_asset3: maven2 Asset 3
        :param str maven2_asset3_classifier: maven2 Asset 3 Classifier
        :param str maven2_asset3_extension: maven2 Asset 3 Extension
        :param file apt_asset: apt Asset 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository', 'yum_directory', 'yum_asset', 'yum_asset_filename', 'r_asset', 'r_asset_path_id', 'rubygems_asset', 'nuget_asset', 'raw_directory', 'raw_asset1', 'raw_asset1_filename', 'raw_asset2', 'raw_asset2_filename', 'raw_asset3', 'raw_asset3_filename', 'pypi_asset', 'npm_asset', 'maven2_group_id', 'maven2_artifact_id', 'maven2_version', 'maven2_generate_pom', 'maven2_packaging', 'maven2_asset1', 'maven2_asset1_classifier', 'maven2_asset1_extension', 'maven2_asset2', 'maven2_asset2_classifier', 'maven2_asset2_extension', 'maven2_asset3', 'maven2_asset3_classifier', 'maven2_asset3_extension', 'apt_asset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_component" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository' is set
        if self.api_client.client_side_validation and ('repository' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository` when calling `upload_component`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'repository' in local_var_params and local_var_params['repository'] is not None:  # noqa: E501
            query_params.append(('repository', local_var_params['repository']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'yum_directory' in local_var_params:
            form_params.append(('yum.directory', local_var_params['yum_directory']))  # noqa: E501
        if 'yum_asset' in local_var_params:
            local_var_files['yum.asset'] = local_var_params['yum_asset']  # noqa: E501
        if 'yum_asset_filename' in local_var_params:
            form_params.append(('yum.asset.filename', local_var_params['yum_asset_filename']))  # noqa: E501
        if 'r_asset' in local_var_params:
            local_var_files['r.asset'] = local_var_params['r_asset']  # noqa: E501
        if 'r_asset_path_id' in local_var_params:
            form_params.append(('r.asset.pathId', local_var_params['r_asset_path_id']))  # noqa: E501
        if 'rubygems_asset' in local_var_params:
            local_var_files['rubygems.asset'] = local_var_params['rubygems_asset']  # noqa: E501
        if 'nuget_asset' in local_var_params:
            local_var_files['nuget.asset'] = local_var_params['nuget_asset']  # noqa: E501
        if 'raw_directory' in local_var_params:
            form_params.append(('raw.directory', local_var_params['raw_directory']))  # noqa: E501
        if 'raw_asset1' in local_var_params:
            local_var_files['raw.asset1'] = local_var_params['raw_asset1']  # noqa: E501
        if 'raw_asset1_filename' in local_var_params:
            form_params.append(('raw.asset1.filename', local_var_params['raw_asset1_filename']))  # noqa: E501
        if 'raw_asset2' in local_var_params:
            local_var_files['raw.asset2'] = local_var_params['raw_asset2']  # noqa: E501
        if 'raw_asset2_filename' in local_var_params:
            form_params.append(('raw.asset2.filename', local_var_params['raw_asset2_filename']))  # noqa: E501
        if 'raw_asset3' in local_var_params:
            local_var_files['raw.asset3'] = local_var_params['raw_asset3']  # noqa: E501
        if 'raw_asset3_filename' in local_var_params:
            form_params.append(('raw.asset3.filename', local_var_params['raw_asset3_filename']))  # noqa: E501
        if 'pypi_asset' in local_var_params:
            local_var_files['pypi.asset'] = local_var_params['pypi_asset']  # noqa: E501
        if 'npm_asset' in local_var_params:
            local_var_files['npm.asset'] = local_var_params['npm_asset']  # noqa: E501
        if 'maven2_group_id' in local_var_params:
            form_params.append(('maven2.groupId', local_var_params['maven2_group_id']))  # noqa: E501
        if 'maven2_artifact_id' in local_var_params:
            form_params.append(('maven2.artifactId', local_var_params['maven2_artifact_id']))  # noqa: E501
        if 'maven2_version' in local_var_params:
            form_params.append(('maven2.version', local_var_params['maven2_version']))  # noqa: E501
        if 'maven2_generate_pom' in local_var_params:
            form_params.append(('maven2.generate-pom', local_var_params['maven2_generate_pom']))  # noqa: E501
        if 'maven2_packaging' in local_var_params:
            form_params.append(('maven2.packaging', local_var_params['maven2_packaging']))  # noqa: E501
        if 'maven2_asset1' in local_var_params:
            local_var_files['maven2.asset1'] = local_var_params['maven2_asset1']  # noqa: E501
        if 'maven2_asset1_classifier' in local_var_params:
            form_params.append(('maven2.asset1.classifier', local_var_params['maven2_asset1_classifier']))  # noqa: E501
        if 'maven2_asset1_extension' in local_var_params:
            form_params.append(('maven2.asset1.extension', local_var_params['maven2_asset1_extension']))  # noqa: E501
        if 'maven2_asset2' in local_var_params:
            local_var_files['maven2.asset2'] = local_var_params['maven2_asset2']  # noqa: E501
        if 'maven2_asset2_classifier' in local_var_params:
            form_params.append(('maven2.asset2.classifier', local_var_params['maven2_asset2_classifier']))  # noqa: E501
        if 'maven2_asset2_extension' in local_var_params:
            form_params.append(('maven2.asset2.extension', local_var_params['maven2_asset2_extension']))  # noqa: E501
        if 'maven2_asset3' in local_var_params:
            local_var_files['maven2.asset3'] = local_var_params['maven2_asset3']  # noqa: E501
        if 'maven2_asset3_classifier' in local_var_params:
            form_params.append(('maven2.asset3.classifier', local_var_params['maven2_asset3_classifier']))  # noqa: E501
        if 'maven2_asset3_extension' in local_var_params:
            form_params.append(('maven2.asset3.extension', local_var_params['maven2_asset3_extension']))  # noqa: E501
        if 'apt_asset' in local_var_params:
            local_var_files['apt.asset'] = local_var_params['apt_asset']  # noqa: E501

        body_params = None
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/components', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class TaskXO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'type': 'str',
        'message': 'str',
        'current_state': 'str',
        'last_run_result': 'str',
        'next_run': 'datetime',
        'last_run': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'type': 'type',
        'message': 'message',
        'current_state': 'currentState',
        'last_run_result': 'lastRunResult',
        'next_run': 'nextRun',
        'last_run': 'lastRun'
    }

    def __init__(self, id=None, name=None, type=None, message=None, current_state=None, last_run_result=None, next_run=None, last_run=None, local_vars_configuration=None):  # noqa: E501
        """TaskXO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._type = None
        self._message = None
        self._current_state = None
        self._last_run_result = None
        self._next_run = None
        self._last_run = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if message is not None:
            self.message = message
        if current_state is not None:
            self.current_state = current_state
        if last_run_result is not None:
            self.last_run_result = last_run_result
        if next_run is not None:
            self.next_run = next_run
        if last_run is not None:
            self.last_run = last_run

    @property
    def id(self):
        """Gets the id of this TaskXO.  # noqa: E501


        :return: The id of this TaskXO.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TaskXO.


        :param id: The id of this TaskXO.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this TaskXO.  # noqa: E501


        :return: The name of this TaskXO.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaskXO.


        :param name: The name of this TaskXO.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this TaskXO.  # noqa: E501


        :return: The type of this TaskXO.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TaskXO.


        :param type: The type of this TaskXO.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def message(self):
        """Gets the message of this TaskXO.  # noqa: E501


        :return: The message of this TaskXO.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this TaskXO.


        :param message: The message of this TaskXO.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def current_state(self):
        """Gets the current_state of this TaskXO.  # noqa: E501


        :return: The current_state of this TaskXO.  # noqa: E501
        :rtype: str
        """
        return self._current_state

    @current_state.setter
    def current_state(self, current_state):
        """Sets the current_state of this TaskXO.


        :param current_state: The current_state of this TaskXO.  # noqa: E501
        :type: str
        """

        self._current_state = current_state

    @property
    def last_run_result(self):
        """Gets the last_run_result of this TaskXO.  # noqa: E501


        :return: The last_run_result of this TaskXO.  # noqa: E501
        :rtype: str
        """
        return self._last_run_result

    @last_run_result.setter
    def last_run_result(self, last_run_result):
        """Sets the last_run_result of this TaskXO.


        :param last_run_result: The last_run_result of this TaskXO.  # noqa: E501
        :type: str
        """

        self._last_run_result = last_run_result

    @property
    def next_run(self):
        """Gets the next_run of this TaskXO.  # noqa: E501


        :return: The next_run of this TaskXO.  # noqa: E501
        :rtype: datetime
        """
        return self._next_run

    @next_run.setter
    def next_run(self, next_run):
        """Sets the next_run of this TaskXO.


        :param next_run: The next_run of this TaskXO.  # noqa: E501
        :type: datetime
        """

        self._next_run = next_run

    @property
    def last_run(self):
        """Gets the last_run of this TaskXO.  # noqa: E501


        :return: The last_run of this TaskXO.  # noqa: E501
        :rtype: datetime
        """
        return self._last_run

    @last_run.setter
    def last_run(self, last_run):
        """Sets the last_run of this TaskXO.


        :param last_run: The last_run of this TaskXO.  # noqa: E501
        :type: datetime
        """

        self._last_run = last_run

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskXO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TaskXO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from nexus_api_python_client.api.blob_store_api import BlobStoreApi
from nexus_api_python_client.api.manage_iq_server_configuration_api import ManageIQServerConfigurationApi
from nexus_api_python_client.api.product_licensing_api import ProductLicensingApi
from nexus_api_python_client.api.repository_management_api import RepositoryManagementApi
from nexus_api_python_client.api.security_certificates_api import SecurityCertificatesApi
from nexus_api_python_client.api.security_management_api import SecurityManagementApi
from nexus_api_python_client.api.security_management_ldap_api import SecurityManagementLDAPApi
from nexus_api_python_client.api.security_management_privileges_api import SecurityManagementPrivilegesApi
from nexus_api_python_client.api.security_management_realms_api import SecurityManagementRealmsApi
from nexus_api_python_client.api.security_management_roles_api import SecurityManagementRolesApi
from nexus_api_python_client.api.security_management_users_api import SecurityManagementUsersApi
from nexus_api_python_client.api.assets_api import AssetsApi
from nexus_api_python_client.api.components_api import ComponentsApi
from nexus_api_python_client.api.content_selectors_api import ContentSelectorsApi
from nexus_api_python_client.api.email_api import EmailApi
from nexus_api_python_client.api.formats_api import FormatsApi
from nexus_api_python_client.api.lifecycle_api import LifecycleApi
from nexus_api_python_client.api.read_only_api import ReadOnlyApi
from nexus_api_python_client.api.repositories_api import RepositoriesApi
from nexus_api_python_client.api.routing_rules_api import RoutingRulesApi
from nexus_api_python_client.api.script_api import ScriptApi
from nexus_api_python_client.api.search_api import SearchApi
from nexus_api_python_client.api.status_api import StatusApi
from nexus_api_python_client.api.support_api import SupportApi
from nexus_api_python_client.api.tasks_api import TasksApi

# import ApiClient
from nexus_api_python_client.api_client import ApiClient
from nexus_api_python_client.configuration import Configuration
from nexus_api_python_client.exceptions import OpenApiException
from nexus_api_python_client.exceptions import ApiTypeError
from nexus_api_python_client.exceptions import ApiValueError
from nexus_api_python_client.exceptions import ApiKeyError
from nexus_api_python_client.exceptions import ApiException
# import models into sdk package
from nexus_api_python_client.models.abstract_api_repository import AbstractApiRepository
from nexus_api_python_client.models.api_certificate import ApiCertificate
from nexus_api_python_client.models.api_create_user import ApiCreateUser
from nexus_api_python_client.models.api_email_configuration import ApiEmailConfiguration
from nexus_api_python_client.models.api_email_validation import ApiEmailValidation
from nexus_api_python_client.models.api_license_details_xo import ApiLicenseDetailsXO
from nexus_api_python_client.models.api_privilege import ApiPrivilege
from nexus_api_python_client.models.api_privilege_application_request import ApiPrivilegeApplicationRequest
from nexus_api_python_client.models.api_privilege_repository_admin_request import ApiPrivilegeRepositoryAdminRequest
from nexus_api_python_client.models.api_privilege_repository_content_selector_request import ApiPrivilegeRepositoryContentSelectorRequest
from nexus_api_python_client.models.api_privilege_repository_view_request import ApiPrivilegeRepositoryViewRequest
from nexus_api_python_client.models.api_privilege_script_request import ApiPrivilegeScriptRequest
from nexus_api_python_client.models.api_privilege_wildcard_request import ApiPrivilegeWildcardRequest
from nexus_api_python_client.models.api_user import ApiUser
from nexus_api_python_client.models.api_user_source import ApiUserSource
from nexus_api_python_client.models.apt_hosted_repositories_attributes import AptHostedRepositoriesAttributes
from nexus_api_python_client.models.apt_hosted_repository_api_request import AptHostedRepositoryApiRequest
from nexus_api_python_client.models.apt_proxy_repositories_attributes import AptProxyRepositoriesAttributes
from nexus_api_python_client.models.apt_proxy_repository_api_request import AptProxyRepositoryApiRequest
from nexus_api_python_client.models.apt_signing_repositories_attributes import AptSigningRepositoriesAttributes
from nexus_api_python_client.models.asset_xo import AssetXO
from nexus_api_python_client.models.blob_store_api_soft_quota import BlobStoreApiSoftQuota
from nexus_api_python_client.models.blob_store_quota_result_xo import BlobStoreQuotaResultXO
from nexus_api_python_client.models.bower_attributes import BowerAttributes
from nexus_api_python_client.models.bower_group_repository_api_request import BowerGroupRepositoryApiRequest
from nexus_api_python_client.models.bower_hosted_repository_api_request import BowerHostedRepositoryApiRequest
from nexus_api_python_client.models.bower_proxy_repository_api_request import BowerProxyRepositoryApiRequest
from nexus_api_python_client.models.cleanup_policy_attributes import CleanupPolicyAttributes
from nexus_api_python_client.models.component_xo import ComponentXO
from nexus_api_python_client.models.content_selector_api_create_request import ContentSelectorApiCreateRequest
from nexus_api_python_client.models.content_selector_api_response import ContentSelectorApiResponse
from nexus_api_python_client.models.content_selector_api_update_request import ContentSelectorApiUpdateRequest
from nexus_api_python_client.models.create_ldap_server_xo import CreateLdapServerXo
from nexus_api_python_client.models.docker_attributes import DockerAttributes
from nexus_api_python_client.models.docker_group_repository_api_request import DockerGroupRepositoryApiRequest
from nexus_api_python_client.models.docker_hosted_repository_api_request import DockerHostedRepositoryApiRequest
from nexus_api_python_client.models.docker_proxy_attributes import DockerProxyAttributes
from nexus_api_python_client.models.docker_proxy_repository_api_request import DockerProxyRepositoryApiRequest
from nexus_api_python_client.models.file_blob_store_api_create_request import FileBlobStoreApiCreateRequest
from nexus_api_python_client.models.file_blob_store_api_model import FileBlobStoreApiModel
from nexus_api_python_client.models.file_blob_store_api_update_request import FileBlobStoreApiUpdateRequest
from nexus_api_python_client.models.generic_blob_store_api_response import GenericBlobStoreApiResponse
from nexus_api_python_client.models.git_lfs_hosted_repository_api_request import GitLfsHostedRepositoryApiRequest
from nexus_api_python_client.models.golang_group_repository_api_request import GolangGroupRepositoryApiRequest
from nexus_api_python_client.models.golang_proxy_repository_api_request import GolangProxyRepositoryApiRequest
from nexus_api_python_client.models.group_attributes import GroupAttributes
from nexus_api_python_client.models.hosted_storage_attributes import HostedStorageAttributes
from nexus_api_python_client.models.http_client_attributes import HttpClientAttributes
from nexus_api_python_client.models.http_client_connection_attributes import HttpClientConnectionAttributes
from nexus_api_python_client.models.http_client_connection_authentication_attributes import HttpClientConnectionAuthenticationAttributes
from nexus_api_python_client.models.iq_connection_verification_xo import IqConnectionVerificationXo
from nexus_api_python_client.models.iq_connection_xo import IqConnectionXo
from nexus_api_python_client.models.negative_cache_attributes import NegativeCacheAttributes
from nexus_api_python_client.models.page import Page
from nexus_api_python_client.models.page_asset_xo import PageAssetXO
from nexus_api_python_client.models.page_component_xo import PageComponentXO
from nexus_api_python_client.models.page_task_xo import PageTaskXO
from nexus_api_python_client.models.proxy_attributes import ProxyAttributes
from nexus_api_python_client.models.read_ldap_server_xo import ReadLdapServerXo
from nexus_api_python_client.models.read_only_state import ReadOnlyState
from nexus_api_python_client.models.realm_api_xo import RealmApiXO
from nexus_api_python_client.models.repository_xo import RepositoryXO
from nexus_api_python_client.models.request import Request
from nexus_api_python_client.models.result import Result
from nexus_api_python_client.models.role_xo_request import RoleXORequest
from nexus_api_python_client.models.role_xo_response import RoleXOResponse
from nexus_api_python_client.models.routing_rule_xo import RoutingRuleXO
from nexus_api_python_client.models.s3_blob_store_api_advanced_bucket_connection import S3BlobStoreApiAdvancedBucketConnection
from nexus_api_python_client.models.s3_blob_store_api_bucket import S3BlobStoreApiBucket
from nexus_api_python_client.models.s3_blob_store_api_bucket_configuration import S3BlobStoreApiBucketConfiguration
from nexus_api_python_client.models.s3_blob_store_api_bucket_security import S3BlobStoreApiBucketSecurity
from nexus_api_python_client.models.s3_blob_store_api_encryption import S3BlobStoreApiEncryption
from nexus_api_python_client.models.s3_blob_store_api_model import S3BlobStoreApiModel
from nexus_api_python_client.models.script_result_xo import ScriptResultXO
from nexus_api_python_client.models.script_xo import ScriptXO
from nexus_api_python_client.models.stack_trace_element import StackTraceElement
from nexus_api_python_client.models.storage_attributes import StorageAttributes
from nexus_api_python_client.models.task_xo import TaskXO
from nexus_api_python_client.models.throwable import Throwable
from nexus_api_python_client.models.update_ldap_server_xo import UpdateLdapServerXo
from nexus_api_python_client.models.upload_definition_xo import UploadDefinitionXO
from nexus_api_python_client.models.upload_field_definition_xo import UploadFieldDefinitionXO




# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from nexus_api_python_client.api_client import ApiClient
from nexus_api_python_client.exceptions import (
    ApiTypeError,
    ApiValueError
)


class SecurityCertificatesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_certificate(self, **kwargs):  # noqa: E501
        """Add a certificate to the trust store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_certificate(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str body: The certificate to add encoded in PEM format
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_certificate_with_http_info(**kwargs)  # noqa: E501

    def add_certificate_with_http_info(self, **kwargs):  # noqa: E501
        """Add a certificate to the trust store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_certificate_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str body: The certificate to add encoded in PEM format
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_certificate" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/security/ssl/truststore', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_trust_store_certificates(self, **kwargs):  # noqa: E501
        """Retrieve a list of certificates added to the trust store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_trust_store_certificates(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ApiCertificate]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_trust_store_certificates_with_http_info(**kwargs)  # noqa: E501

    def get_trust_store_certificates_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve a list of certificates added to the trust store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_trust_store_certificates_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ApiCertificate], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_trust_store_certificates" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/security/ssl/truststore', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ApiCertificate]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_certificate(self, id, **kwargs):  # noqa: E501
        """Remove a certificate in the trust store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_certificate(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the certificate that should be removed. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_certificate_with_http_info(id, **kwargs)  # noqa: E501

    def remove_certificate_with_http_info(self, id, **kwargs):  # noqa: E501
        """Remove a certificate in the trust store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_certificate_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the certificate that should be removed. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_certificate" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `remove_certificate`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/security/ssl/truststore/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_certificate(self, host, **kwargs):  # noqa: E501
        """Helper method to retrieve certificate details from a remote system.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_certificate(host, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str host: The remote system's host name (required)
        :param int port: The port on the remote system to connect to
        :param str protocol_hint: An optional hint of the protocol to try for the connection
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ApiCertificate
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.retrieve_certificate_with_http_info(host, **kwargs)  # noqa: E501

    def retrieve_certificate_with_http_info(self, host, **kwargs):  # noqa: E501
        """Helper method to retrieve certificate details from a remote system.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_certificate_with_http_info(host, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str host: The remote system's host name (required)
        :param int port: The port on the remote system to connect to
        :param str protocol_hint: An optional hint of the protocol to try for the connection
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ApiCertificate, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['host', 'port', 'protocol_hint']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_certificate" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'host' is set
        if self.api_client.client_side_validation and ('host' not in local_var_params or  # noqa: E501
                                                        local_var_params['host'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `host` when calling `retrieve_certificate`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'host' in local_var_params and local_var_params['host'] is not None:  # noqa: E501
            query_params.append(('host', local_var_params['host']))  # noqa: E501
        if 'port' in local_var_params and local_var_params['port'] is not None:  # noqa: E501
            query_params.append(('port', local_var_params['port']))  # noqa: E501
        if 'protocol_hint' in local_var_params and local_var_params['protocol_hint'] is not None:  # noqa: E501
            query_params.append(('protocolHint', local_var_params['protocol_hint']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/security/ssl', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiCertificate',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class Result(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'healthy': 'bool',
        'message': 'str',
        'error': 'Throwable',
        'details': 'dict(str, object)',
        'time': 'int',
        'duration': 'int',
        'timestamp': 'str'
    }

    attribute_map = {
        'healthy': 'healthy',
        'message': 'message',
        'error': 'error',
        'details': 'details',
        'time': 'time',
        'duration': 'duration',
        'timestamp': 'timestamp'
    }

    def __init__(self, healthy=None, message=None, error=None, details=None, time=None, duration=None, timestamp=None, local_vars_configuration=None):  # noqa: E501
        """Result - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._healthy = None
        self._message = None
        self._error = None
        self._details = None
        self._time = None
        self._duration = None
        self._timestamp = None
        self.discriminator = None

        if healthy is not None:
            self.healthy = healthy
        if message is not None:
            self.message = message
        if error is not None:
            self.error = error
        if details is not None:
            self.details = details
        if time is not None:
            self.time = time
        if duration is not None:
            self.duration = duration
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def healthy(self):
        """Gets the healthy of this Result.  # noqa: E501


        :return: The healthy of this Result.  # noqa: E501
        :rtype: bool
        """
        return self._healthy

    @healthy.setter
    def healthy(self, healthy):
        """Sets the healthy of this Result.


        :param healthy: The healthy of this Result.  # noqa: E501
        :type: bool
        """

        self._healthy = healthy

    @property
    def message(self):
        """Gets the message of this Result.  # noqa: E501


        :return: The message of this Result.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Result.


        :param message: The message of this Result.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def error(self):
        """Gets the error of this Result.  # noqa: E501


        :return: The error of this Result.  # noqa: E501
        :rtype: Throwable
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this Result.


        :param error: The error of this Result.  # noqa: E501
        :type: Throwable
        """

        self._error = error

    @property
    def details(self):
        """Gets the details of this Result.  # noqa: E501


        :return: The details of this Result.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this Result.


        :param details: The details of this Result.  # noqa: E501
        :type: dict(str, object)
        """

        self._details = details

    @property
    def time(self):
        """Gets the time of this Result.  # noqa: E501


        :return: The time of this Result.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this Result.


        :param time: The time of this Result.  # noqa: E501
        :type: int
        """

        self._time = time

    @property
    def duration(self):
        """Gets the duration of this Result.  # noqa: E501


        :return: The duration of this Result.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this Result.


        :param duration: The duration of this Result.  # noqa: E501
        :type: int
        """

        self._duration = duration

    @property
    def timestamp(self):
        """Gets the timestamp of this Result.  # noqa: E501


        :return: The timestamp of this Result.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Result.


        :param timestamp: The timestamp of this Result.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Result):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Result):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class DockerGroupRepositoryApiRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'online': 'bool',
        'storage': 'StorageAttributes',
        'group': 'GroupAttributes',
        'docker': 'DockerAttributes'
    }

    attribute_map = {
        'name': 'name',
        'online': 'online',
        'storage': 'storage',
        'group': 'group',
        'docker': 'docker'
    }

    def __init__(self, name=None, online=None, storage=None, group=None, docker=None, local_vars_configuration=None):  # noqa: E501
        """DockerGroupRepositoryApiRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._online = None
        self._storage = None
        self._group = None
        self._docker = None
        self.discriminator = None

        self.name = name
        self.online = online
        self.storage = storage
        self.group = group
        self.docker = docker

    @property
    def name(self):
        """Gets the name of this DockerGroupRepositoryApiRequest.  # noqa: E501

        A unique identifier for this repository  # noqa: E501

        :return: The name of this DockerGroupRepositoryApiRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DockerGroupRepositoryApiRequest.

        A unique identifier for this repository  # noqa: E501

        :param name: The name of this DockerGroupRepositoryApiRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def online(self):
        """Gets the online of this DockerGroupRepositoryApiRequest.  # noqa: E501

        Whether this repository accepts incoming requests  # noqa: E501

        :return: The online of this DockerGroupRepositoryApiRequest.  # noqa: E501
        :rtype: bool
        """
        return self._online

    @online.setter
    def online(self, online):
        """Sets the online of this DockerGroupRepositoryApiRequest.

        Whether this repository accepts incoming requests  # noqa: E501

        :param online: The online of this DockerGroupRepositoryApiRequest.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and online is None:  # noqa: E501
            raise ValueError("Invalid value for `online`, must not be `None`")  # noqa: E501

        self._online = online

    @property
    def storage(self):
        """Gets the storage of this DockerGroupRepositoryApiRequest.  # noqa: E501


        :return: The storage of this DockerGroupRepositoryApiRequest.  # noqa: E501
        :rtype: StorageAttributes
        """
        return self._storage

    @storage.setter
    def storage(self, storage):
        """Sets the storage of this DockerGroupRepositoryApiRequest.


        :param storage: The storage of this DockerGroupRepositoryApiRequest.  # noqa: E501
        :type: StorageAttributes
        """
        if self.local_vars_configuration.client_side_validation and storage is None:  # noqa: E501
            raise ValueError("Invalid value for `storage`, must not be `None`")  # noqa: E501

        self._storage = storage

    @property
    def group(self):
        """Gets the group of this DockerGroupRepositoryApiRequest.  # noqa: E501


        :return: The group of this DockerGroupRepositoryApiRequest.  # noqa: E501
        :rtype: GroupAttributes
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this DockerGroupRepositoryApiRequest.


        :param group: The group of this DockerGroupRepositoryApiRequest.  # noqa: E501
        :type: GroupAttributes
        """
        if self.local_vars_configuration.client_side_validation and group is None:  # noqa: E501
            raise ValueError("Invalid value for `group`, must not be `None`")  # noqa: E501

        self._group = group

    @property
    def docker(self):
        """Gets the docker of this DockerGroupRepositoryApiRequest.  # noqa: E501


        :return: The docker of this DockerGroupRepositoryApiRequest.  # noqa: E501
        :rtype: DockerAttributes
        """
        return self._docker

    @docker.setter
    def docker(self, docker):
        """Sets the docker of this DockerGroupRepositoryApiRequest.


        :param docker: The docker of this DockerGroupRepositoryApiRequest.  # noqa: E501
        :type: DockerAttributes
        """
        if self.local_vars_configuration.client_side_validation and docker is None:  # noqa: E501
            raise ValueError("Invalid value for `docker`, must not be `None`")  # noqa: E501

        self._docker = docker

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DockerGroupRepositoryApiRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DockerGroupRepositoryApiRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from nexus_api_python_client.api_client import ApiClient
from nexus_api_python_client.exceptions import (
    ApiTypeError,
    ApiValueError
)


class SecurityManagementRolesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create(self, body, **kwargs):  # noqa: E501
        """Create role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RoleXORequest body: A role configuration (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RoleXOResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_with_http_info(body, **kwargs)  # noqa: E501

    def create_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RoleXORequest body: A role configuration (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RoleXOResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/security/roles', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RoleXOResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete(self, id, **kwargs):  # noqa: E501
        """Delete role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the role to delete (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_with_http_info(id, **kwargs)  # noqa: E501

    def delete_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the role to delete (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/security/roles/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_role(self, id, **kwargs):  # noqa: E501
        """Get role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_role(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the role to get (required)
        :param str source: The id of the user source to filter the roles by. Available sources can be fetched using the 'User Sources' endpoint.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RoleXOResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_role_with_http_info(id, **kwargs)  # noqa: E501

    def get_role_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_role_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the role to get (required)
        :param str source: The id of the user source to filter the roles by. Available sources can be fetched using the 'User Sources' endpoint.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RoleXOResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id', 'source']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_role" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'source' in local_var_params and local_var_params['source'] is not None:  # noqa: E501
            query_params.append(('source', local_var_params['source']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/security/roles/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RoleXOResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_roles(self, **kwargs):  # noqa: E501
        """List roles  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_roles(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str source: The id of the user source to filter the roles by, if supplied. Otherwise roles from all user sources will be returned.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[RoleXOResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_roles_with_http_info(**kwargs)  # noqa: E501

    def get_roles_with_http_info(self, **kwargs):  # noqa: E501
        """List roles  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_roles_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str source: The id of the user source to filter the roles by, if supplied. Otherwise roles from all user sources will be returned.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[RoleXOResponse], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['source']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_roles" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'source' in local_var_params and local_var_params['source'] is not None:  # noqa: E501
            query_params.append(('source', local_var_params['source']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/security/roles', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RoleXOResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update(self, id, body, **kwargs):  # noqa: E501
        """Update role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update(id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the role to update (required)
        :param RoleXORequest body: A role configuration (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_with_http_info(id, body, **kwargs)  # noqa: E501

    def update_with_http_info(self, id, body, **kwargs):  # noqa: E501
        """Update role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_with_http_info(id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the role to update (required)
        :param RoleXORequest body: A role configuration (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `update`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/security/roles/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class CreateLdapServerXo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'protocol': 'str',
        'use_trust_store': 'bool',
        'host': 'str',
        'port': 'int',
        'search_base': 'str',
        'auth_scheme': 'str',
        'auth_realm': 'str',
        'auth_username': 'str',
        'connection_timeout_seconds': 'int',
        'connection_retry_delay_seconds': 'int',
        'max_incidents_count': 'int',
        'user_base_dn': 'str',
        'user_subtree': 'bool',
        'user_object_class': 'str',
        'user_ldap_filter': 'str',
        'user_id_attribute': 'str',
        'user_real_name_attribute': 'str',
        'user_email_address_attribute': 'str',
        'user_password_attribute': 'str',
        'ldap_groups_as_roles': 'bool',
        'group_type': 'str',
        'group_base_dn': 'str',
        'group_subtree': 'bool',
        'group_object_class': 'str',
        'group_id_attribute': 'str',
        'group_member_attribute': 'str',
        'group_member_format': 'str',
        'user_member_of_attribute': 'str',
        'auth_password': 'str'
    }

    attribute_map = {
        'name': 'name',
        'protocol': 'protocol',
        'use_trust_store': 'useTrustStore',
        'host': 'host',
        'port': 'port',
        'search_base': 'searchBase',
        'auth_scheme': 'authScheme',
        'auth_realm': 'authRealm',
        'auth_username': 'authUsername',
        'connection_timeout_seconds': 'connectionTimeoutSeconds',
        'connection_retry_delay_seconds': 'connectionRetryDelaySeconds',
        'max_incidents_count': 'maxIncidentsCount',
        'user_base_dn': 'userBaseDn',
        'user_subtree': 'userSubtree',
        'user_object_class': 'userObjectClass',
        'user_ldap_filter': 'userLdapFilter',
        'user_id_attribute': 'userIdAttribute',
        'user_real_name_attribute': 'userRealNameAttribute',
        'user_email_address_attribute': 'userEmailAddressAttribute',
        'user_password_attribute': 'userPasswordAttribute',
        'ldap_groups_as_roles': 'ldapGroupsAsRoles',
        'group_type': 'groupType',
        'group_base_dn': 'groupBaseDn',
        'group_subtree': 'groupSubtree',
        'group_object_class': 'groupObjectClass',
        'group_id_attribute': 'groupIdAttribute',
        'group_member_attribute': 'groupMemberAttribute',
        'group_member_format': 'groupMemberFormat',
        'user_member_of_attribute': 'userMemberOfAttribute',
        'auth_password': 'authPassword'
    }

    def __init__(self, name=None, protocol=None, use_trust_store=None, host=None, port=None, search_base=None, auth_scheme=None, auth_realm=None, auth_username=None, connection_timeout_seconds=None, connection_retry_delay_seconds=None, max_incidents_count=None, user_base_dn=None, user_subtree=None, user_object_class=None, user_ldap_filter=None, user_id_attribute=None, user_real_name_attribute=None, user_email_address_attribute=None, user_password_attribute=None, ldap_groups_as_roles=None, group_type=None, group_base_dn=None, group_subtree=None, group_object_class=None, group_id_attribute=None, group_member_attribute=None, group_member_format=None, user_member_of_attribute=None, auth_password=None, local_vars_configuration=None):  # noqa: E501
        """CreateLdapServerXo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._protocol = None
        self._use_trust_store = None
        self._host = None
        self._port = None
        self._search_base = None
        self._auth_scheme = None
        self._auth_realm = None
        self._auth_username = None
        self._connection_timeout_seconds = None
        self._connection_retry_delay_seconds = None
        self._max_incidents_count = None
        self._user_base_dn = None
        self._user_subtree = None
        self._user_object_class = None
        self._user_ldap_filter = None
        self._user_id_attribute = None
        self._user_real_name_attribute = None
        self._user_email_address_attribute = None
        self._user_password_attribute = None
        self._ldap_groups_as_roles = None
        self._group_type = None
        self._group_base_dn = None
        self._group_subtree = None
        self._group_object_class = None
        self._group_id_attribute = None
        self._group_member_attribute = None
        self._group_member_format = None
        self._user_member_of_attribute = None
        self._auth_password = None
        self.discriminator = None

        self.name = name
        self.protocol = protocol
        if use_trust_store is not None:
            self.use_trust_store = use_trust_store
        self.host = host
        self.port = port
        self.search_base = search_base
        self.auth_scheme = auth_scheme
        if auth_realm is not None:
            self.auth_realm = auth_realm
        if auth_username is not None:
            self.auth_username = auth_username
        self.connection_timeout_seconds = connection_timeout_seconds
        self.connection_retry_delay_seconds = connection_retry_delay_seconds
        self.max_incidents_count = max_incidents_count
        if user_base_dn is not None:
            self.user_base_dn = user_base_dn
        if user_subtree is not None:
            self.user_subtree = user_subtree
        if user_object_class is not None:
            self.user_object_class = user_object_class
        if user_ldap_filter is not None:
            self.user_ldap_filter = user_ldap_filter
        if user_id_attribute is not None:
            self.user_id_attribute = user_id_attribute
        if user_real_name_attribute is not None:
            self.user_real_name_attribute = user_real_name_attribute
        if user_email_address_attribute is not None:
            self.user_email_address_attribute = user_email_address_attribute
        if user_password_attribute is not None:
            self.user_password_attribute = user_password_attribute
        if ldap_groups_as_roles is not None:
            self.ldap_groups_as_roles = ldap_groups_as_roles
        self.group_type = group_type
        if group_base_dn is not None:
            self.group_base_dn = group_base_dn
        if group_subtree is not None:
            self.group_subtree = group_subtree
        if group_object_class is not None:
            self.group_object_class = group_object_class
        if group_id_attribute is not None:
            self.group_id_attribute = group_id_attribute
        if group_member_attribute is not None:
            self.group_member_attribute = group_member_attribute
        if group_member_format is not None:
            self.group_member_format = group_member_format
        if user_member_of_attribute is not None:
            self.user_member_of_attribute = user_member_of_attribute
        self.auth_password = auth_password

    @property
    def name(self):
        """Gets the name of this CreateLdapServerXo.  # noqa: E501

        LDAP server name  # noqa: E501

        :return: The name of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateLdapServerXo.

        LDAP server name  # noqa: E501

        :param name: The name of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def protocol(self):
        """Gets the protocol of this CreateLdapServerXo.  # noqa: E501

        LDAP server connection Protocol to use  # noqa: E501

        :return: The protocol of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this CreateLdapServerXo.

        LDAP server connection Protocol to use  # noqa: E501

        :param protocol: The protocol of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and protocol is None:  # noqa: E501
            raise ValueError("Invalid value for `protocol`, must not be `None`")  # noqa: E501
        allowed_values = ["ldap", "ldaps"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and protocol not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `protocol` ({0}), must be one of {1}"  # noqa: E501
                .format(protocol, allowed_values)
            )

        self._protocol = protocol

    @property
    def use_trust_store(self):
        """Gets the use_trust_store of this CreateLdapServerXo.  # noqa: E501

        Whether to use certificates stored in NXRM's truststore  # noqa: E501

        :return: The use_trust_store of this CreateLdapServerXo.  # noqa: E501
        :rtype: bool
        """
        return self._use_trust_store

    @use_trust_store.setter
    def use_trust_store(self, use_trust_store):
        """Sets the use_trust_store of this CreateLdapServerXo.

        Whether to use certificates stored in NXRM's truststore  # noqa: E501

        :param use_trust_store: The use_trust_store of this CreateLdapServerXo.  # noqa: E501
        :type: bool
        """

        self._use_trust_store = use_trust_store

    @property
    def host(self):
        """Gets the host of this CreateLdapServerXo.  # noqa: E501

        LDAP server connection hostname  # noqa: E501

        :return: The host of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this CreateLdapServerXo.

        LDAP server connection hostname  # noqa: E501

        :param host: The host of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and host is None:  # noqa: E501
            raise ValueError("Invalid value for `host`, must not be `None`")  # noqa: E501

        self._host = host

    @property
    def port(self):
        """Gets the port of this CreateLdapServerXo.  # noqa: E501

        LDAP server connection port to use  # noqa: E501

        :return: The port of this CreateLdapServerXo.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this CreateLdapServerXo.

        LDAP server connection port to use  # noqa: E501

        :param port: The port of this CreateLdapServerXo.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and port is None:  # noqa: E501
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501

        self._port = port

    @property
    def search_base(self):
        """Gets the search_base of this CreateLdapServerXo.  # noqa: E501

        LDAP location to be added to the connection URL  # noqa: E501

        :return: The search_base of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._search_base

    @search_base.setter
    def search_base(self, search_base):
        """Sets the search_base of this CreateLdapServerXo.

        LDAP location to be added to the connection URL  # noqa: E501

        :param search_base: The search_base of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and search_base is None:  # noqa: E501
            raise ValueError("Invalid value for `search_base`, must not be `None`")  # noqa: E501

        self._search_base = search_base

    @property
    def auth_scheme(self):
        """Gets the auth_scheme of this CreateLdapServerXo.  # noqa: E501

        Authentication scheme used for connecting to LDAP server  # noqa: E501

        :return: The auth_scheme of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._auth_scheme

    @auth_scheme.setter
    def auth_scheme(self, auth_scheme):
        """Sets the auth_scheme of this CreateLdapServerXo.

        Authentication scheme used for connecting to LDAP server  # noqa: E501

        :param auth_scheme: The auth_scheme of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and auth_scheme is None:  # noqa: E501
            raise ValueError("Invalid value for `auth_scheme`, must not be `None`")  # noqa: E501
        allowed_values = ["NONE", "SIMPLE", "DIGEST_MD5", "CRAM_MD5"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and auth_scheme not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `auth_scheme` ({0}), must be one of {1}"  # noqa: E501
                .format(auth_scheme, allowed_values)
            )

        self._auth_scheme = auth_scheme

    @property
    def auth_realm(self):
        """Gets the auth_realm of this CreateLdapServerXo.  # noqa: E501

        The SASL realm to bind to. Required if authScheme is CRAM_MD5 or DIGEST_MD5  # noqa: E501

        :return: The auth_realm of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._auth_realm

    @auth_realm.setter
    def auth_realm(self, auth_realm):
        """Sets the auth_realm of this CreateLdapServerXo.

        The SASL realm to bind to. Required if authScheme is CRAM_MD5 or DIGEST_MD5  # noqa: E501

        :param auth_realm: The auth_realm of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """

        self._auth_realm = auth_realm

    @property
    def auth_username(self):
        """Gets the auth_username of this CreateLdapServerXo.  # noqa: E501

        This must be a fully qualified username if simple authentication is used. Required if authScheme other than none.  # noqa: E501

        :return: The auth_username of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._auth_username

    @auth_username.setter
    def auth_username(self, auth_username):
        """Sets the auth_username of this CreateLdapServerXo.

        This must be a fully qualified username if simple authentication is used. Required if authScheme other than none.  # noqa: E501

        :param auth_username: The auth_username of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """

        self._auth_username = auth_username

    @property
    def connection_timeout_seconds(self):
        """Gets the connection_timeout_seconds of this CreateLdapServerXo.  # noqa: E501

        How long to wait before timeout  # noqa: E501

        :return: The connection_timeout_seconds of this CreateLdapServerXo.  # noqa: E501
        :rtype: int
        """
        return self._connection_timeout_seconds

    @connection_timeout_seconds.setter
    def connection_timeout_seconds(self, connection_timeout_seconds):
        """Sets the connection_timeout_seconds of this CreateLdapServerXo.

        How long to wait before timeout  # noqa: E501

        :param connection_timeout_seconds: The connection_timeout_seconds of this CreateLdapServerXo.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and connection_timeout_seconds is None:  # noqa: E501
            raise ValueError("Invalid value for `connection_timeout_seconds`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connection_timeout_seconds is not None and connection_timeout_seconds > 3600):  # noqa: E501
            raise ValueError("Invalid value for `connection_timeout_seconds`, must be a value less than or equal to `3600`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connection_timeout_seconds is not None and connection_timeout_seconds < 1):  # noqa: E501
            raise ValueError("Invalid value for `connection_timeout_seconds`, must be a value greater than or equal to `1`")  # noqa: E501

        self._connection_timeout_seconds = connection_timeout_seconds

    @property
    def connection_retry_delay_seconds(self):
        """Gets the connection_retry_delay_seconds of this CreateLdapServerXo.  # noqa: E501

        How long to wait before retrying  # noqa: E501

        :return: The connection_retry_delay_seconds of this CreateLdapServerXo.  # noqa: E501
        :rtype: int
        """
        return self._connection_retry_delay_seconds

    @connection_retry_delay_seconds.setter
    def connection_retry_delay_seconds(self, connection_retry_delay_seconds):
        """Sets the connection_retry_delay_seconds of this CreateLdapServerXo.

        How long to wait before retrying  # noqa: E501

        :param connection_retry_delay_seconds: The connection_retry_delay_seconds of this CreateLdapServerXo.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and connection_retry_delay_seconds is None:  # noqa: E501
            raise ValueError("Invalid value for `connection_retry_delay_seconds`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connection_retry_delay_seconds is not None and connection_retry_delay_seconds < 0):  # noqa: E501
            raise ValueError("Invalid value for `connection_retry_delay_seconds`, must be a value greater than or equal to `0`")  # noqa: E501

        self._connection_retry_delay_seconds = connection_retry_delay_seconds

    @property
    def max_incidents_count(self):
        """Gets the max_incidents_count of this CreateLdapServerXo.  # noqa: E501

        How many retry attempts  # noqa: E501

        :return: The max_incidents_count of this CreateLdapServerXo.  # noqa: E501
        :rtype: int
        """
        return self._max_incidents_count

    @max_incidents_count.setter
    def max_incidents_count(self, max_incidents_count):
        """Sets the max_incidents_count of this CreateLdapServerXo.

        How many retry attempts  # noqa: E501

        :param max_incidents_count: The max_incidents_count of this CreateLdapServerXo.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and max_incidents_count is None:  # noqa: E501
            raise ValueError("Invalid value for `max_incidents_count`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_incidents_count is not None and max_incidents_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_incidents_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_incidents_count = max_incidents_count

    @property
    def user_base_dn(self):
        """Gets the user_base_dn of this CreateLdapServerXo.  # noqa: E501

        The relative DN where user objects are found (e.g. ou=people). This value will have the Search base DN value appended to form the full User search base DN.  # noqa: E501

        :return: The user_base_dn of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._user_base_dn

    @user_base_dn.setter
    def user_base_dn(self, user_base_dn):
        """Sets the user_base_dn of this CreateLdapServerXo.

        The relative DN where user objects are found (e.g. ou=people). This value will have the Search base DN value appended to form the full User search base DN.  # noqa: E501

        :param user_base_dn: The user_base_dn of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """

        self._user_base_dn = user_base_dn

    @property
    def user_subtree(self):
        """Gets the user_subtree of this CreateLdapServerXo.  # noqa: E501

        Are users located in structures below the user base DN?  # noqa: E501

        :return: The user_subtree of this CreateLdapServerXo.  # noqa: E501
        :rtype: bool
        """
        return self._user_subtree

    @user_subtree.setter
    def user_subtree(self, user_subtree):
        """Sets the user_subtree of this CreateLdapServerXo.

        Are users located in structures below the user base DN?  # noqa: E501

        :param user_subtree: The user_subtree of this CreateLdapServerXo.  # noqa: E501
        :type: bool
        """

        self._user_subtree = user_subtree

    @property
    def user_object_class(self):
        """Gets the user_object_class of this CreateLdapServerXo.  # noqa: E501

        LDAP class for user objects  # noqa: E501

        :return: The user_object_class of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._user_object_class

    @user_object_class.setter
    def user_object_class(self, user_object_class):
        """Sets the user_object_class of this CreateLdapServerXo.

        LDAP class for user objects  # noqa: E501

        :param user_object_class: The user_object_class of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """

        self._user_object_class = user_object_class

    @property
    def user_ldap_filter(self):
        """Gets the user_ldap_filter of this CreateLdapServerXo.  # noqa: E501

        LDAP search filter to limit user search  # noqa: E501

        :return: The user_ldap_filter of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._user_ldap_filter

    @user_ldap_filter.setter
    def user_ldap_filter(self, user_ldap_filter):
        """Sets the user_ldap_filter of this CreateLdapServerXo.

        LDAP search filter to limit user search  # noqa: E501

        :param user_ldap_filter: The user_ldap_filter of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """

        self._user_ldap_filter = user_ldap_filter

    @property
    def user_id_attribute(self):
        """Gets the user_id_attribute of this CreateLdapServerXo.  # noqa: E501

        This is used to find a user given its user ID  # noqa: E501

        :return: The user_id_attribute of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._user_id_attribute

    @user_id_attribute.setter
    def user_id_attribute(self, user_id_attribute):
        """Sets the user_id_attribute of this CreateLdapServerXo.

        This is used to find a user given its user ID  # noqa: E501

        :param user_id_attribute: The user_id_attribute of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """

        self._user_id_attribute = user_id_attribute

    @property
    def user_real_name_attribute(self):
        """Gets the user_real_name_attribute of this CreateLdapServerXo.  # noqa: E501

        This is used to find a real name given the user ID  # noqa: E501

        :return: The user_real_name_attribute of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._user_real_name_attribute

    @user_real_name_attribute.setter
    def user_real_name_attribute(self, user_real_name_attribute):
        """Sets the user_real_name_attribute of this CreateLdapServerXo.

        This is used to find a real name given the user ID  # noqa: E501

        :param user_real_name_attribute: The user_real_name_attribute of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """

        self._user_real_name_attribute = user_real_name_attribute

    @property
    def user_email_address_attribute(self):
        """Gets the user_email_address_attribute of this CreateLdapServerXo.  # noqa: E501

        This is used to find an email address given the user ID  # noqa: E501

        :return: The user_email_address_attribute of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._user_email_address_attribute

    @user_email_address_attribute.setter
    def user_email_address_attribute(self, user_email_address_attribute):
        """Sets the user_email_address_attribute of this CreateLdapServerXo.

        This is used to find an email address given the user ID  # noqa: E501

        :param user_email_address_attribute: The user_email_address_attribute of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """

        self._user_email_address_attribute = user_email_address_attribute

    @property
    def user_password_attribute(self):
        """Gets the user_password_attribute of this CreateLdapServerXo.  # noqa: E501

        If this field is blank the user will be authenticated against a bind with the LDAP server  # noqa: E501

        :return: The user_password_attribute of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._user_password_attribute

    @user_password_attribute.setter
    def user_password_attribute(self, user_password_attribute):
        """Sets the user_password_attribute of this CreateLdapServerXo.

        If this field is blank the user will be authenticated against a bind with the LDAP server  # noqa: E501

        :param user_password_attribute: The user_password_attribute of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """

        self._user_password_attribute = user_password_attribute

    @property
    def ldap_groups_as_roles(self):
        """Gets the ldap_groups_as_roles of this CreateLdapServerXo.  # noqa: E501

        Denotes whether LDAP assigned roles are used as NXRM roles  # noqa: E501

        :return: The ldap_groups_as_roles of this CreateLdapServerXo.  # noqa: E501
        :rtype: bool
        """
        return self._ldap_groups_as_roles

    @ldap_groups_as_roles.setter
    def ldap_groups_as_roles(self, ldap_groups_as_roles):
        """Sets the ldap_groups_as_roles of this CreateLdapServerXo.

        Denotes whether LDAP assigned roles are used as NXRM roles  # noqa: E501

        :param ldap_groups_as_roles: The ldap_groups_as_roles of this CreateLdapServerXo.  # noqa: E501
        :type: bool
        """

        self._ldap_groups_as_roles = ldap_groups_as_roles

    @property
    def group_type(self):
        """Gets the group_type of this CreateLdapServerXo.  # noqa: E501

        Defines a type of groups used: static (a group contains a list of users) or dynamic (a user contains a list of groups). Required if ldapGroupsAsRoles is true.  # noqa: E501

        :return: The group_type of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._group_type

    @group_type.setter
    def group_type(self, group_type):
        """Sets the group_type of this CreateLdapServerXo.

        Defines a type of groups used: static (a group contains a list of users) or dynamic (a user contains a list of groups). Required if ldapGroupsAsRoles is true.  # noqa: E501

        :param group_type: The group_type of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and group_type is None:  # noqa: E501
            raise ValueError("Invalid value for `group_type`, must not be `None`")  # noqa: E501
        allowed_values = ["static", "dynamic"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and group_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `group_type` ({0}), must be one of {1}"  # noqa: E501
                .format(group_type, allowed_values)
            )

        self._group_type = group_type

    @property
    def group_base_dn(self):
        """Gets the group_base_dn of this CreateLdapServerXo.  # noqa: E501

        The relative DN where group objects are found (e.g. ou=Group). This value will have the Search base DN value appended to form the full Group search base DN.  # noqa: E501

        :return: The group_base_dn of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._group_base_dn

    @group_base_dn.setter
    def group_base_dn(self, group_base_dn):
        """Sets the group_base_dn of this CreateLdapServerXo.

        The relative DN where group objects are found (e.g. ou=Group). This value will have the Search base DN value appended to form the full Group search base DN.  # noqa: E501

        :param group_base_dn: The group_base_dn of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """

        self._group_base_dn = group_base_dn

    @property
    def group_subtree(self):
        """Gets the group_subtree of this CreateLdapServerXo.  # noqa: E501

        Are groups located in structures below the group base DN  # noqa: E501

        :return: The group_subtree of this CreateLdapServerXo.  # noqa: E501
        :rtype: bool
        """
        return self._group_subtree

    @group_subtree.setter
    def group_subtree(self, group_subtree):
        """Sets the group_subtree of this CreateLdapServerXo.

        Are groups located in structures below the group base DN  # noqa: E501

        :param group_subtree: The group_subtree of this CreateLdapServerXo.  # noqa: E501
        :type: bool
        """

        self._group_subtree = group_subtree

    @property
    def group_object_class(self):
        """Gets the group_object_class of this CreateLdapServerXo.  # noqa: E501

        LDAP class for group objects. Required if groupType is static  # noqa: E501

        :return: The group_object_class of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._group_object_class

    @group_object_class.setter
    def group_object_class(self, group_object_class):
        """Sets the group_object_class of this CreateLdapServerXo.

        LDAP class for group objects. Required if groupType is static  # noqa: E501

        :param group_object_class: The group_object_class of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                group_object_class is not None and len(group_object_class) > 0):
            raise ValueError("Invalid value for `group_object_class`, length must be less than or equal to `0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                group_object_class is not None and len(group_object_class) < 0):
            raise ValueError("Invalid value for `group_object_class`, length must be greater than or equal to `0`")  # noqa: E501

        self._group_object_class = group_object_class

    @property
    def group_id_attribute(self):
        """Gets the group_id_attribute of this CreateLdapServerXo.  # noqa: E501

        This field specifies the attribute of the Object class that defines the Group ID. Required if groupType is static  # noqa: E501

        :return: The group_id_attribute of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._group_id_attribute

    @group_id_attribute.setter
    def group_id_attribute(self, group_id_attribute):
        """Sets the group_id_attribute of this CreateLdapServerXo.

        This field specifies the attribute of the Object class that defines the Group ID. Required if groupType is static  # noqa: E501

        :param group_id_attribute: The group_id_attribute of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                group_id_attribute is not None and len(group_id_attribute) > 0):
            raise ValueError("Invalid value for `group_id_attribute`, length must be less than or equal to `0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                group_id_attribute is not None and len(group_id_attribute) < 0):
            raise ValueError("Invalid value for `group_id_attribute`, length must be greater than or equal to `0`")  # noqa: E501

        self._group_id_attribute = group_id_attribute

    @property
    def group_member_attribute(self):
        """Gets the group_member_attribute of this CreateLdapServerXo.  # noqa: E501

        LDAP attribute containing the usernames for the group. Required if groupType is static  # noqa: E501

        :return: The group_member_attribute of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._group_member_attribute

    @group_member_attribute.setter
    def group_member_attribute(self, group_member_attribute):
        """Sets the group_member_attribute of this CreateLdapServerXo.

        LDAP attribute containing the usernames for the group. Required if groupType is static  # noqa: E501

        :param group_member_attribute: The group_member_attribute of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                group_member_attribute is not None and len(group_member_attribute) > 0):
            raise ValueError("Invalid value for `group_member_attribute`, length must be less than or equal to `0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                group_member_attribute is not None and len(group_member_attribute) < 0):
            raise ValueError("Invalid value for `group_member_attribute`, length must be greater than or equal to `0`")  # noqa: E501

        self._group_member_attribute = group_member_attribute

    @property
    def group_member_format(self):
        """Gets the group_member_format of this CreateLdapServerXo.  # noqa: E501

        The format of user ID stored in the group member attribute. Required if groupType is static  # noqa: E501

        :return: The group_member_format of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._group_member_format

    @group_member_format.setter
    def group_member_format(self, group_member_format):
        """Sets the group_member_format of this CreateLdapServerXo.

        The format of user ID stored in the group member attribute. Required if groupType is static  # noqa: E501

        :param group_member_format: The group_member_format of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                group_member_format is not None and len(group_member_format) > 0):
            raise ValueError("Invalid value for `group_member_format`, length must be less than or equal to `0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                group_member_format is not None and len(group_member_format) < 0):
            raise ValueError("Invalid value for `group_member_format`, length must be greater than or equal to `0`")  # noqa: E501

        self._group_member_format = group_member_format

    @property
    def user_member_of_attribute(self):
        """Gets the user_member_of_attribute of this CreateLdapServerXo.  # noqa: E501

        Set this to the attribute used to store the attribute which holds groups DN in the user object. Required if groupType is dynamic  # noqa: E501

        :return: The user_member_of_attribute of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._user_member_of_attribute

    @user_member_of_attribute.setter
    def user_member_of_attribute(self, user_member_of_attribute):
        """Sets the user_member_of_attribute of this CreateLdapServerXo.

        Set this to the attribute used to store the attribute which holds groups DN in the user object. Required if groupType is dynamic  # noqa: E501

        :param user_member_of_attribute: The user_member_of_attribute of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                user_member_of_attribute is not None and len(user_member_of_attribute) > 0):
            raise ValueError("Invalid value for `user_member_of_attribute`, length must be less than or equal to `0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                user_member_of_attribute is not None and len(user_member_of_attribute) < 0):
            raise ValueError("Invalid value for `user_member_of_attribute`, length must be greater than or equal to `0`")  # noqa: E501

        self._user_member_of_attribute = user_member_of_attribute

    @property
    def auth_password(self):
        """Gets the auth_password of this CreateLdapServerXo.  # noqa: E501

        The password to bind with. Required if authScheme other than none.  # noqa: E501

        :return: The auth_password of this CreateLdapServerXo.  # noqa: E501
        :rtype: str
        """
        return self._auth_password

    @auth_password.setter
    def auth_password(self, auth_password):
        """Sets the auth_password of this CreateLdapServerXo.

        The password to bind with. Required if authScheme other than none.  # noqa: E501

        :param auth_password: The auth_password of this CreateLdapServerXo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and auth_password is None:  # noqa: E501
            raise ValueError("Invalid value for `auth_password`, must not be `None`")  # noqa: E501

        self._auth_password = auth_password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateLdapServerXo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateLdapServerXo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class IqConnectionXo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'enabled': 'bool',
        'show_link': 'bool',
        'url': 'str',
        'authentication_type': 'str',
        'username': 'str',
        'password': 'str',
        'use_trust_store_for_url': 'bool',
        'timeout_seconds': 'int',
        'properties': 'str'
    }

    attribute_map = {
        'enabled': 'enabled',
        'show_link': 'showLink',
        'url': 'url',
        'authentication_type': 'authenticationType',
        'username': 'username',
        'password': 'password',
        'use_trust_store_for_url': 'useTrustStoreForUrl',
        'timeout_seconds': 'timeoutSeconds',
        'properties': 'properties'
    }

    def __init__(self, enabled=None, show_link=None, url=None, authentication_type=None, username=None, password=None, use_trust_store_for_url=None, timeout_seconds=None, properties=None, local_vars_configuration=None):  # noqa: E501
        """IqConnectionXo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._enabled = None
        self._show_link = None
        self._url = None
        self._authentication_type = None
        self._username = None
        self._password = None
        self._use_trust_store_for_url = None
        self._timeout_seconds = None
        self._properties = None
        self.discriminator = None

        if enabled is not None:
            self.enabled = enabled
        if show_link is not None:
            self.show_link = show_link
        if url is not None:
            self.url = url
        self.authentication_type = authentication_type
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password
        if use_trust_store_for_url is not None:
            self.use_trust_store_for_url = use_trust_store_for_url
        if timeout_seconds is not None:
            self.timeout_seconds = timeout_seconds
        if properties is not None:
            self.properties = properties

    @property
    def enabled(self):
        """Gets the enabled of this IqConnectionXo.  # noqa: E501

        Whether to use IQ Server  # noqa: E501

        :return: The enabled of this IqConnectionXo.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this IqConnectionXo.

        Whether to use IQ Server  # noqa: E501

        :param enabled: The enabled of this IqConnectionXo.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def show_link(self):
        """Gets the show_link of this IqConnectionXo.  # noqa: E501

        Show IQ Server link in Browse menu when server is enabled  # noqa: E501

        :return: The show_link of this IqConnectionXo.  # noqa: E501
        :rtype: bool
        """
        return self._show_link

    @show_link.setter
    def show_link(self, show_link):
        """Sets the show_link of this IqConnectionXo.

        Show IQ Server link in Browse menu when server is enabled  # noqa: E501

        :param show_link: The show_link of this IqConnectionXo.  # noqa: E501
        :type: bool
        """

        self._show_link = show_link

    @property
    def url(self):
        """Gets the url of this IqConnectionXo.  # noqa: E501

        The address of your IQ Server  # noqa: E501

        :return: The url of this IqConnectionXo.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this IqConnectionXo.

        The address of your IQ Server  # noqa: E501

        :param url: The url of this IqConnectionXo.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def authentication_type(self):
        """Gets the authentication_type of this IqConnectionXo.  # noqa: E501

        Authentication method  # noqa: E501

        :return: The authentication_type of this IqConnectionXo.  # noqa: E501
        :rtype: str
        """
        return self._authentication_type

    @authentication_type.setter
    def authentication_type(self, authentication_type):
        """Sets the authentication_type of this IqConnectionXo.

        Authentication method  # noqa: E501

        :param authentication_type: The authentication_type of this IqConnectionXo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and authentication_type is None:  # noqa: E501
            raise ValueError("Invalid value for `authentication_type`, must not be `None`")  # noqa: E501
        allowed_values = ["USER", "PKI"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and authentication_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `authentication_type` ({0}), must be one of {1}"  # noqa: E501
                .format(authentication_type, allowed_values)
            )

        self._authentication_type = authentication_type

    @property
    def username(self):
        """Gets the username of this IqConnectionXo.  # noqa: E501

        User with access to IQ Server  # noqa: E501

        :return: The username of this IqConnectionXo.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this IqConnectionXo.

        User with access to IQ Server  # noqa: E501

        :param username: The username of this IqConnectionXo.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def password(self):
        """Gets the password of this IqConnectionXo.  # noqa: E501

        Credentials for the IQ Server User  # noqa: E501

        :return: The password of this IqConnectionXo.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this IqConnectionXo.

        Credentials for the IQ Server User  # noqa: E501

        :param password: The password of this IqConnectionXo.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def use_trust_store_for_url(self):
        """Gets the use_trust_store_for_url of this IqConnectionXo.  # noqa: E501

        Use certificates stored in the Nexus truststore to connect to IQ Server  # noqa: E501

        :return: The use_trust_store_for_url of this IqConnectionXo.  # noqa: E501
        :rtype: bool
        """
        return self._use_trust_store_for_url

    @use_trust_store_for_url.setter
    def use_trust_store_for_url(self, use_trust_store_for_url):
        """Sets the use_trust_store_for_url of this IqConnectionXo.

        Use certificates stored in the Nexus truststore to connect to IQ Server  # noqa: E501

        :param use_trust_store_for_url: The use_trust_store_for_url of this IqConnectionXo.  # noqa: E501
        :type: bool
        """

        self._use_trust_store_for_url = use_trust_store_for_url

    @property
    def timeout_seconds(self):
        """Gets the timeout_seconds of this IqConnectionXo.  # noqa: E501

        Seconds to wait for activity before stopping and retrying the connection. Leave blank to use the globally defined HTTP timeout.  # noqa: E501

        :return: The timeout_seconds of this IqConnectionXo.  # noqa: E501
        :rtype: int
        """
        return self._timeout_seconds

    @timeout_seconds.setter
    def timeout_seconds(self, timeout_seconds):
        """Sets the timeout_seconds of this IqConnectionXo.

        Seconds to wait for activity before stopping and retrying the connection. Leave blank to use the globally defined HTTP timeout.  # noqa: E501

        :param timeout_seconds: The timeout_seconds of this IqConnectionXo.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                timeout_seconds is not None and timeout_seconds > 3600):  # noqa: E501
            raise ValueError("Invalid value for `timeout_seconds`, must be a value less than or equal to `3600`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                timeout_seconds is not None and timeout_seconds < 1):  # noqa: E501
            raise ValueError("Invalid value for `timeout_seconds`, must be a value greater than or equal to `1`")  # noqa: E501

        self._timeout_seconds = timeout_seconds

    @property
    def properties(self):
        """Gets the properties of this IqConnectionXo.  # noqa: E501

        Additional properties to configure for IQ Server  # noqa: E501

        :return: The properties of this IqConnectionXo.  # noqa: E501
        :rtype: str
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this IqConnectionXo.

        Additional properties to configure for IQ Server  # noqa: E501

        :param properties: The properties of this IqConnectionXo.  # noqa: E501
        :type: str
        """

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IqConnectionXo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IqConnectionXo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class ApiUser(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'email_address': 'str',
        'source': 'str',
        'status': 'str',
        'read_only': 'bool',
        'roles': 'list[str]',
        'external_roles': 'list[str]'
    }

    attribute_map = {
        'user_id': 'userId',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email_address': 'emailAddress',
        'source': 'source',
        'status': 'status',
        'read_only': 'readOnly',
        'roles': 'roles',
        'external_roles': 'externalRoles'
    }

    def __init__(self, user_id=None, first_name=None, last_name=None, email_address=None, source=None, status=None, read_only=None, roles=None, external_roles=None, local_vars_configuration=None):  # noqa: E501
        """ApiUser - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._first_name = None
        self._last_name = None
        self._email_address = None
        self._source = None
        self._status = None
        self._read_only = None
        self._roles = None
        self._external_roles = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email_address is not None:
            self.email_address = email_address
        if source is not None:
            self.source = source
        self.status = status
        if read_only is not None:
            self.read_only = read_only
        if roles is not None:
            self.roles = roles
        if external_roles is not None:
            self.external_roles = external_roles

    @property
    def user_id(self):
        """Gets the user_id of this ApiUser.  # noqa: E501

        The userid which is required for login. This value cannot be changed.  # noqa: E501

        :return: The user_id of this ApiUser.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ApiUser.

        The userid which is required for login. This value cannot be changed.  # noqa: E501

        :param user_id: The user_id of this ApiUser.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def first_name(self):
        """Gets the first_name of this ApiUser.  # noqa: E501

        The first name of the user.  # noqa: E501

        :return: The first_name of this ApiUser.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this ApiUser.

        The first name of the user.  # noqa: E501

        :param first_name: The first_name of this ApiUser.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this ApiUser.  # noqa: E501

        The last name of the user.  # noqa: E501

        :return: The last_name of this ApiUser.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this ApiUser.

        The last name of the user.  # noqa: E501

        :param last_name: The last_name of this ApiUser.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email_address(self):
        """Gets the email_address of this ApiUser.  # noqa: E501

        The email address associated with the user.  # noqa: E501

        :return: The email_address of this ApiUser.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this ApiUser.

        The email address associated with the user.  # noqa: E501

        :param email_address: The email_address of this ApiUser.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def source(self):
        """Gets the source of this ApiUser.  # noqa: E501

        The user source which is the origin of this user. This value cannot be changed.  # noqa: E501

        :return: The source of this ApiUser.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this ApiUser.

        The user source which is the origin of this user. This value cannot be changed.  # noqa: E501

        :param source: The source of this ApiUser.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def status(self):
        """Gets the status of this ApiUser.  # noqa: E501

        The user's status, e.g. active or disabled.  # noqa: E501

        :return: The status of this ApiUser.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ApiUser.

        The user's status, e.g. active or disabled.  # noqa: E501

        :param status: The status of this ApiUser.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["active", "locked", "disabled", "changepassword"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def read_only(self):
        """Gets the read_only of this ApiUser.  # noqa: E501

        Indicates whether the user's properties could be modified by Nexus. When false only roles are considered during update.  # noqa: E501

        :return: The read_only of this ApiUser.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this ApiUser.

        Indicates whether the user's properties could be modified by Nexus. When false only roles are considered during update.  # noqa: E501

        :param read_only: The read_only of this ApiUser.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    @property
    def roles(self):
        """Gets the roles of this ApiUser.  # noqa: E501

        The roles which the user has been assigned within Nexus.  # noqa: E501

        :return: The roles of this ApiUser.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this ApiUser.

        The roles which the user has been assigned within Nexus.  # noqa: E501

        :param roles: The roles of this ApiUser.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    @property
    def external_roles(self):
        """Gets the external_roles of this ApiUser.  # noqa: E501

        The roles which the user has been assigned in an external source, e.g. LDAP group. These cannot be changed within Nexus.  # noqa: E501

        :return: The external_roles of this ApiUser.  # noqa: E501
        :rtype: list[str]
        """
        return self._external_roles

    @external_roles.setter
    def external_roles(self, external_roles):
        """Sets the external_roles of this ApiUser.

        The roles which the user has been assigned in an external source, e.g. LDAP group. These cannot be changed within Nexus.  # noqa: E501

        :param external_roles: The external_roles of this ApiUser.  # noqa: E501
        :type: list[str]
        """

        self._external_roles = external_roles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiUser):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApiUser):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class FileBlobStoreApiCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'soft_quota': 'BlobStoreApiSoftQuota',
        'path': 'str',
        'name': 'str'
    }

    attribute_map = {
        'soft_quota': 'softQuota',
        'path': 'path',
        'name': 'name'
    }

    def __init__(self, soft_quota=None, path=None, name=None, local_vars_configuration=None):  # noqa: E501
        """FileBlobStoreApiCreateRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._soft_quota = None
        self._path = None
        self._name = None
        self.discriminator = None

        if soft_quota is not None:
            self.soft_quota = soft_quota
        if path is not None:
            self.path = path
        if name is not None:
            self.name = name

    @property
    def soft_quota(self):
        """Gets the soft_quota of this FileBlobStoreApiCreateRequest.  # noqa: E501


        :return: The soft_quota of this FileBlobStoreApiCreateRequest.  # noqa: E501
        :rtype: BlobStoreApiSoftQuota
        """
        return self._soft_quota

    @soft_quota.setter
    def soft_quota(self, soft_quota):
        """Sets the soft_quota of this FileBlobStoreApiCreateRequest.


        :param soft_quota: The soft_quota of this FileBlobStoreApiCreateRequest.  # noqa: E501
        :type: BlobStoreApiSoftQuota
        """

        self._soft_quota = soft_quota

    @property
    def path(self):
        """Gets the path of this FileBlobStoreApiCreateRequest.  # noqa: E501

        The path to the blobstore contents. This can be an absolute path to anywhere on the system nxrm has access to or it can be a path relative to the sonatype-work directory.  # noqa: E501

        :return: The path of this FileBlobStoreApiCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this FileBlobStoreApiCreateRequest.

        The path to the blobstore contents. This can be an absolute path to anywhere on the system nxrm has access to or it can be a path relative to the sonatype-work directory.  # noqa: E501

        :param path: The path of this FileBlobStoreApiCreateRequest.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def name(self):
        """Gets the name of this FileBlobStoreApiCreateRequest.  # noqa: E501


        :return: The name of this FileBlobStoreApiCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileBlobStoreApiCreateRequest.


        :param name: The name of this FileBlobStoreApiCreateRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileBlobStoreApiCreateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileBlobStoreApiCreateRequest):
            return True

        return self.to_dict() != other.to_dict()
